models

package
v1.2.0 Latest Latest
Warning

This package is not in the latest version of its module.

Go to latest
Published: Mar 11, 2021 License: MIT Imports: 5 Imported by: 0

Documentation

Index

Constants

This section is empty.

Variables

This section is empty.

Functions

This section is empty.

Types

type AchievementInfo

type AchievementInfo struct {
	*AllAchievementInfo

	Error error `json:"-"`

	Name string
	ID   uint32
	Date time.Time

	NameEN string
	NameJA string
	NameDE string
	NameFR string
}

AchievementInfo represents information about a character's achievements.

type AllAchievementInfo

type AllAchievementInfo struct {
	Private                bool
	TotalAchievements      uint32
	TotalAchievementPoints uint32
}

AllAchievementInfo represents information about a character's achievements in aggregate.

type CWLS

type CWLS struct {
	Name      string
	DC        string
	ID        string
	ParseDate time.Time
	Members   []*CWLSMember
}

CWLS represents basic CWLS information.

type CWLSMember

type CWLSMember struct {
	Avatar            string
	ID                uint32
	Name              string
	LinkshellRank     string
	LinkshellRankIcon string
	Rank              gcrank.GCRank
	RankIcon          string
	World             string
	DC                string
}

CWLSMember represents information about a CWLS member.

type CWLSSearchResult

type CWLSSearchResult struct {
	Error error `json:"-"`

	Name          string
	ID            string
	DC            string
	ActiveMembers uint32
}

CWLSSearchResult represents basic CWLS information returned from a search.

type Character

type Character struct {
	ActiveClassJob    *ClassJob
	Avatar            string
	Bio               string
	ClassJobs         []*ClassJob
	ClassJobBozjan    *ClassJobBozja
	ClassJobElemental *ClassJobEureka
	DC                string
	FreeCompanyID     string
	FreeCompanyName   string
	GearSet           *GearSet
	Gender            gender.Gender
	GrandCompanyInfo  *GrandCompanyInfo
	GuardianDeity     *NamedEntity
	ID                uint32
	Name              string
	Nameday           string
	ParseDate         time.Time
	Portrait          string
	PvPTeamID         string
	Race              *GenderedEntity
	Title             *Title
	Town              *NamedEntity
	Tribe             *GenderedEntity
	World             string
}

Character represents the information available about a character on The Lodestone.

type CharacterSearchResult

type CharacterSearchResult struct {
	Error error `json:"-"`

	Avatar   string
	ID       uint32
	Lang     string
	Name     string
	Rank     gcrank.GCRank
	RankIcon string
	World    string
	DC       string
}

CharacterSearchResult contains data from the character search page about a character.

type ClassJob

type ClassJob struct {
	ClassID       uint8
	ExpLevel      uint32
	ExpLevelMax   uint32
	ExpLevelTogo  uint32
	IsSpecialized bool
	JobID         uint8
	Level         uint8
	Name          string
	UnlockedState UnlockedState
}

ClassJob represents class and job information.

type ClassJobBozja

type ClassJobBozja struct {
	Level  uint8
	Mettle uint32
	Name   string
}

ClassJobBozja represents character progression data in the Bozjan Southern Front.

type ClassJobEureka

type ClassJobEureka struct {
	ExpLevel     uint32
	ExpLevelMax  uint32
	ExpLevelTogo uint32
	Level        uint8
	Name         string
}

ClassJobEureka represents character progression data in Eureka.

type CrestLayers

type CrestLayers struct {
	Bottom string
	Middle string
	Top    string
}

CrestLayers represents the layers of a community crest.

type Estate

type Estate struct {
	Greeting string
	Name     string
	Plot     string
}

Estate represents a housing area estate.

type FreeCompany

type FreeCompany struct {
	Active            FreeCompanyActiveState
	ActiveMemberCount uint32
	CrestLayers       *CrestLayers
	DC                string
	Estate            *Estate
	Focus             []*FreeCompanyFocusInfo
	Formed            time.Time
	GrandCompany      *NamedEntity
	ID                string
	Name              string
	ParseDate         time.Time
	Rank              uint8
	Ranking           *FreeCompanyRanking
	Recruitment       FreeCompanyRecruitingState
	Reputation        []*FreeCompanyReputation
	Seeking           []*FreeCompanySeekingInfo
	Slogan            string
	Tag               string
	World             string
}

FreeCompany represents all of the basic information about an FC.

type FreeCompanyActiveState

type FreeCompanyActiveState string

FreeCompanyActiveState is the active state of an FC.

const (
	FCActiveNotSpecified FreeCompanyActiveState = "Not specified"
	FCActiveWeekdaysOnly FreeCompanyActiveState = "Weekdays Only"
	FCActiveWeekendsOnly FreeCompanyActiveState = "Weekends Only"
	FCActiveAlways       FreeCompanyActiveState = "Always"
)

Active state for an FC.

type FreeCompanyFocus

type FreeCompanyFocus string

FreeCompanyFocus is an FC's focus.

const (
	FCFocusRolePlaying FreeCompanyFocus = "Role-playing"
	FCFocusLeveling    FreeCompanyFocus = "Leveling"
	FCFocusCasual      FreeCompanyFocus = "Casual"
	FCFocusHardcore    FreeCompanyFocus = "Hardcore"
	FCFocusDungeons    FreeCompanyFocus = "Dungeons"
	FCFocusGuildhests  FreeCompanyFocus = "Guildhests"
	FCFocusTrials      FreeCompanyFocus = "Trials"
	FCFocusRaids       FreeCompanyFocus = "Raids"
	FCFocusPvP         FreeCompanyFocus = "PvP"
)

Free Company Focus.

type FreeCompanyFocusInfo

type FreeCompanyFocusInfo struct {
	Icon   string
	Kind   FreeCompanyFocus
	Status bool
}

FreeCompanyFocusInfo represents a particular FC's intentions for a focus.

type FreeCompanyMember

type FreeCompanyMember struct {
	Error error `json:"-"`

	Avatar   string
	ID       uint32
	Name     string
	Rank     gcrank.GCRank
	RankIcon string
	World    string
	DC       string
}

FreeCompanyMember represents information about a Free Company member.

type FreeCompanyRanking

type FreeCompanyRanking struct {
	Monthly uint32
	Weekly  uint32
}

FreeCompanyRanking represents a particular FC's periodic rankings.

type FreeCompanyRecruitingState

type FreeCompanyRecruitingState string

FreeCompanyRecruitingState is the recruiting state of an FC.

const (
	FCRecruitmentClosed FreeCompanyRecruitingState = "Closed"
	FCRecruitmentOpen   FreeCompanyRecruitingState = "Open"
)

Recruiting state for an FC.

type FreeCompanyReputation

type FreeCompanyReputation struct {
	GrandCompany *NamedEntity
	Progress     uint8
	Rank         *NamedEntity
}

FreeCompanyReputation represents an FC's alignment with each Grand Company.

type FreeCompanySearchResult

type FreeCompanySearchResult struct {
	Error error `json:"-"`

	Active        FreeCompanyActiveState
	ActiveMembers uint32
	CrestLayers   *CrestLayers
	DC            string
	Estate        string
	Formed        time.Time
	GrandCompany  *NamedEntity
	ID            string
	Name          string
	Recruitment   FreeCompanyRecruitingState
	World         string
}

FreeCompanySearchResult represents all of the searchable information about an FC.

type FreeCompanySeekingInfo

type FreeCompanySeekingInfo struct {
	Icon   string
	Kind   role.Role
	Status bool
}

FreeCompanySeekingInfo represents a particular FC's intentions for a recruit roles.

type GearItem

type GearItem struct {
	Name    string
	Creator string
	Dye     uint32
	ID      uint32
	HQ      bool
	Materia []uint32
	Mirage  uint32

	NameEN string
	NameJA string
	NameDE string
	NameFR string
}

GearItem represents information about a single gear item on a character.

type GearItemBuild

type GearItemBuild struct {
	Body        *GearItem
	Bracelets   *GearItem
	Earrings    *GearItem
	Feet        *GearItem
	Hands       *GearItem
	Head        *GearItem
	Legs        *GearItem
	MainHand    *GearItem
	Necklace    *GearItem
	OffHand     *GearItem
	Ring1       *GearItem
	Ring2       *GearItem
	SoulCrystal *GearItem
	Waist       *GearItem
}

GearItemBuild represents a full gearset on a character. All gear items can be nil.

type GearSet

type GearSet struct {
	Attributes map[baseparam.BaseParam]uint32
	ClassID    uint8
	Gear       *GearItemBuild
	GearKey    string
	JobID      uint8
	Level      uint8
}

GearSet represents the current gear information of a character.

type GenderedEntity

type GenderedEntity struct {
	ID   uint32
	Name string

	NameMasculineEN string
	NameMasculineJA string
	NameMasculineDE string
	NameMasculineFR string
	NameFeminineEN  string
	NameFeminineJA  string
	NameFeminineDE  string
	NameFeminineFR  string
}

GenderedEntity represents an instance of an object with masculine and feminine names.

type GrandCompanyInfo

type GrandCompanyInfo struct {
	GrandCompany *NamedEntity
	RankID       gcrank.GCRank
}

GrandCompanyInfo represents Grand Company information about a character.

type Linkshell

type Linkshell struct {
	Name      string
	ID        string
	ParseDate time.Time
	Members   []*LinkshellMember
}

Linkshell represents basic linkshell information.

type LinkshellMember

type LinkshellMember struct {
	Avatar            string
	ID                uint32
	Name              string
	LinkshellRank     string
	LinkshellRankIcon string
	Rank              gcrank.GCRank
	RankIcon          string
	World             string
	DC                string
}

LinkshellMember represents information about a linkshell member.

type LinkshellSearchResult

type LinkshellSearchResult struct {
	Error error `json:"-"`

	Name          string
	ID            string
	World         string
	DC            string
	ActiveMembers uint32
}

LinkshellSearchResult represents basic linkshell information returned from a search.

type Meta

type Meta struct {
	Version          string `json:"version"`
	UserAgentDesktop string `json:"userAgentDesktop"`
	UserAgentMobile  string `json:"userAgentMobile"`
}

Meta is meta.

type Minion

type Minion struct {
	ID   uint32
	Name string
	Icon string

	NameEN string
	NameDE string
	NameFR string
	NameJA string
}

Minion represents a minion.

type Mount

type Mount struct {
	ID   uint32
	Name string
	Icon string

	NameEN string
	NameDE string
	NameFR string
	NameJA string
}

Mount represents a mount.

type NamedEntity

type NamedEntity struct {
	ID   uint32
	Name string
	Icon string

	NameEN string
	NameJA string
	NameDE string
	NameFR string
}

NamedEntity represents an instance of an object with a name.

type PVPTeam

type PVPTeam struct {
	Name        string
	ID          string
	DC          string
	ParseDate   time.Time
	Formed      time.Time
	CrestLayers *CrestLayers
	Members     []*PVPTeamMember
}

PVPTeam represents information about a PVP team.

type PVPTeamMember

type PVPTeamMember struct {
	Avatar   string
	ID       uint32
	Name     string
	Matches  uint32
	Rank     gcrank.GCRank
	RankIcon string
	World    string
	DC       string
}

PVPTeamMember represents information about a PVP team member.

type PVPTeamSearchResult

type PVPTeamSearchResult struct {
	Error error `json:"-"`

	Name        string
	ID          string
	DC          string
	CrestLayers *CrestLayers
}

PVPTeamSearchResult represents basic PVP team information returned from a search.

type PageInfo added in v1.1.0

type PageInfo struct {
	CurrentPage int
	TotalPages  int
}

PageInfo represents pagination information in a search.

type Title

type Title struct {
	*GenderedEntity

	Prefix bool
}

Title represents a character title.

type UnlockedState

type UnlockedState struct {
	ID   uint8
	Name string
}

UnlockedState represents the unlock state of a ClassJob

Jump to